#ifndef __WRG313_API_H__
#define __WRG313_API_H__

#include <stdint.h>

#define WRG3APINAME "wrg315api"


#pragma pack(push,1)

typedef struct
{
    uint32_t    Size;
    uint8_t     InterfaceType;
    char        Path[64];
    uint8_t     HasFMW;
    uint8_t     USVersion;
    char        SerNum[9];
    char        Model[9];
    uint32_t    MinFreq;
    uint32_t    MaxFreq;
} RADIO_INFO;

typedef struct
{
    uint32_t Type;
    union
    {
        struct
        {
            uint32_t LastFrequency;
            uint32_t NextFrequency;
        } NextStep;

        struct
        {
            uint32_t Frequency;
            float    Slevel;
            uint8_t  RAW;
            float   *Spectrum;
            uint32_t SpectrumSize; 
        } Result;
    };
} SCANNING_DATA,*PSCANNING_DATA;


typedef struct
{
    uint32_t Size;
    float    AMDepth;
    int32_t  FMDeviation;
    float    TuneError;
    uint32_t NoiseLevel;
} STATISTICS,*PSTATISTICS;

#pragma pack(pop)

#define INTERFACE_TYPE_PCI 0
#define INTERFACE_TYPE_USB 1

#define SCANNING_CALLBACK_DATA_NEXTSTEP      0
#define SCANNING_CALLBACK_DATA_RESULT        1

#define RADIOMODE_CW    0
#define RADIOMODE_AM    1
#define RADIOMODE_FMN   2
#define RADIOMODE_FMW   3
#define RADIOMODE_LSB   4
#define RADIOMODE_USB   5
#define RADIOMODE_AMS   8
#define RADIOMODE_DSB   13
#define RADIOMODE_ISB   14

#define AGC_NONE        0
#define AGC_SLOW        1
#define AGC_MEDIUM      2
#define AGC_FAST        3

#define SPECTRUM_SIZE_64    0
#define SPECTRUM_SIZE_128   1
#define SPECTRUM_SIZE_256   2
#define SPECTRUM_SIZE_512   3
#define SPECTRUM_SIZE_1024  4

#define LED_CONTINUOUSLY_OFF    0
#define LED_CONTINUOUSLY_ON     1
#define LED_DIAGNOSTIC_STATUS   2

#define ISB_AUDIO_CHANNEL_LEFT  0
#define ISB_AUDIO_CHANNEL_RIGHT 1

extern "C"
{
typedef void (*WRG315_AUDIO_CALLBACK)(int16_t *Audio,int16_t *FilteredAudio,uint32_t Count,void *Data);
typedef void (*WRG315_IF_CALLBACK)(int16_t *IF,int32_t Count,void *Data);
typedef void (*WRG315_IFSPECTRUM_CALLBACK)(float *Spectrum,uint32_t Count,void *Data);
typedef uint8_t (*WRG315_SCANNINGCALLBACK)(PSCANNING_DATA ScanningData,void *Data);

typedef int32_t (*GET_DEVICE_LIST)(RADIO_INFO **List,uint32_t *Count);
typedef void (*DESTROY_DEVICE_LIST)(RADIO_INFO *List);
typedef int32_t (*OPEN_DEVICE)(const char *DevPath);
typedef void (*CLOSE_DEVICE)(int32_t Handle);
typedef int32_t (*GET_DEVICE_INFO)(int32_t Handle,RADIO_INFO *Info);
typedef int32_t (*GET_POWER)(int32_t Handle,uint32_t *Power);
typedef int32_t (*SET_POWER)(int32_t Handle,uint32_t Power);
typedef int32_t (*GET_FREQUENCY)(int32_t Handle,uint32_t *Frequency);
typedef int32_t (*SET_FREQUENCY)(int32_t Handle,uint32_t Frequency);
typedef int32_t (*GET_VOLUME)(int32_t Handle,uint32_t *Volume);
typedef int32_t (*SET_VOLUME)(int32_t Handle,uint32_t Volume);
typedef int32_t (*GET_MODE)(int32_t Handle,int32_t *Mode);
typedef int32_t (*SET_MODE)(int32_t Handle,int32_t Mode);
typedef int32_t (*SET_AUDIO_CALLBACK)(int32_t Handle,WRG315_AUDIO_CALLBACK Callback,void *Param);
typedef int32_t (*SET_IF_CALLBACK)(int32_t Handle,WRG315_IF_CALLBACK Callback,void *Param);
typedef int32_t (*SET_IF_SPECTRUM_CALLBACK)(int32_t Handle,WRG315_IFSPECTRUM_CALLBACK Callback,void *Param);
typedef int32_t (*GET_IF_SHIFT)(int32_t Handle,int32_t *Shift);
typedef int32_t (*SET_IF_SHIFT)(int32_t Handle,int32_t Shift);
typedef int32_t (*GET_IF_BANDWIDTH)(int32_t Handle,uint32_t *Bandwidth);
typedef int32_t (*SET_IF_BANDWIDTH)(int32_t Handle,uint32_t Bandwidth);
typedef int32_t (*GET_AGC)(int32_t Handle,int32_t *AGC);
typedef int32_t (*SET_AGC)(int32_t Handle,int32_t AGC);
typedef int32_t (*GET_IF_GAIN)(int32_t Handle,uint32_t *Gain);
typedef int32_t (*SET_IF_GAIN)(int32_t Handle,uint32_t Gain);
typedef int32_t (*ENABLE_AUDIO_FILTER)(int32_t Handle,uint32_t Enable);
typedef int32_t (*GET_AUDIO_FILTER)(int32_t Handle,uint32_t *Enabled,uint32_t *Low,uint32_t *High,float *Deemphasis);
typedef int32_t (*SET_AUDIO_FILTER)(int32_t Handle,uint32_t Low,uint32_t High,float Deemphasis);
typedef int32_t (*GET_SOFT_AGC)(int32_t Handle,int32_t *AGC);
typedef int32_t (*SET_SOFT_AGC)(int32_t Handle,int32_t AGC);
typedef int32_t (*GET_NOTCH_FILTER)(int32_t Handle,uint32_t *Enabled,int32_t *Frequency,uint32_t *Bandwidth);
typedef int32_t (*SET_NOTCH_FILTER)(int32_t Handle,int32_t Frequency,uint32_t Bandwidth);
typedef int32_t (*ENABLE_NOTCH_FILTER)(int32_t Handle,uint32_t Enable);
typedef int32_t (*GET_NOISE_BLANKER)(int32_t Handle,uint32_t *Enabled,uint32_t *Threshold);
typedef int32_t (*SET_NOISE_BLANKER)(int32_t Handle,uint32_t Enabled,uint32_t Threshold);
typedef int32_t (*LOAD_CALIBRATION_FILE)(int32_t Handle,const char *FilePath);
typedef int32_t (*UNLOAD_CALIBRATION_FILE)(int32_t Handle);
typedef int32_t (*GET_ATTENUATOR)(int32_t Handle,uint32_t *Enabled);
typedef int32_t (*SET_ATTENUATOR)(int32_t Handle,uint32_t Enable);
typedef int32_t (*GET_RF_AMPLIFIER)(int32_t Handle,uint32_t *Enabled);
typedef int32_t (*SET_RF_AMPLIFIER)(int32_t Handle,uint32_t Enable);
typedef int32_t (*GET_INTERNAL_RSSI)(int32_t Handle,int32_t *RSSI,int32_t *AGC);
typedef int32_t (*GET_RAW_SIGNAL_STRENGTH)(int32_t Handle,uint8_t *Peak,uint8_t *RMS);
typedef int32_t (*GET_SIGNAL_STRENGTH_DBM)(int32_t Handle,float *Peak,float *RMS);
typedef int32_t (*GET_REF_CLOCK)(int32_t Handle,uint32_t *RefClock);
typedef int32_t (*SET_REF_CLOCK)(int32_t Handle,uint32_t RefClock);
typedef int32_t (*STOP_SCANNING)(int32_t Handle);
typedef int32_t (*START_SCANNING)(int32_t Handle,uint32_t FirstFrequency,uint32_t SpectrumSize,uint32_t Settling,WRG315_SCANNINGCALLBACK Callback,void *Context);
typedef int32_t (*GET_FRONT_PANEL_LED)(int32_t Handle,uint32_t *Led);
typedef int32_t (*SET_FRONT_PANEL_LED)(int32_t Handle,uint32_t Led);
typedef int32_t (*IS_DEVICE_CONNECTED)(int32_t Handle,uint32_t *Connected);
typedef int32_t (*GET_AUDIO_GAIN)(int32_t Handle,uint32_t *Gain);
typedef int32_t (*SET_AUDIO_GAIN)(int32_t Handle,uint32_t Gain);
typedef int32_t (*GET_FMAF_SQUELCH_LEVEL)(int32_t Handle,uint32_t *Level);
typedef int32_t (*SET_FMAF_SQUELCH_LEVEL)(int32_t Handle,uint32_t Level);
typedef int32_t (*GET_ISB_AUDIO_CHANNEL)(int32_t Handle,uint32_t *Channel);
typedef int32_t (*SET_ISB_AUDIO_CHANNEL)(int32_t Handle,uint32_t Channel);
typedef int32_t (*GET_CW_TONE)(int32_t Handle,uint32_t *Frequency);
typedef int32_t (*SET_CW_TONE)(int32_t Handle,uint32_t Frequency);
typedef int32_t (*GET_STATISTICS)(int32_t Handle,PSTATISTICS Statistics);
typedef uint32_t (*GET_API_VERSION)(void);


extern GET_DEVICE_LIST GetDeviceList;
extern DESTROY_DEVICE_LIST DestroyDeviceList;
extern OPEN_DEVICE OpenDevice;
extern CLOSE_DEVICE CloseDevice;
extern GET_DEVICE_INFO GetDeviceInfo;
extern GET_POWER GetPower;
extern SET_POWER SetPower;
extern GET_FREQUENCY GetFrequency;
extern SET_FREQUENCY SetFrequency;
extern GET_VOLUME GetVolume;
extern SET_VOLUME SetVolume;
extern GET_MODE GetMode;
extern SET_MODE SetMode;
extern SET_AUDIO_CALLBACK SetAudioCallback;
extern SET_IF_CALLBACK SetIFCallback;
extern SET_IF_SPECTRUM_CALLBACK SetIFSpectrumCallback;
extern GET_IF_SHIFT GetIFShift;
extern SET_IF_SHIFT SetIFShift;
extern GET_IF_BANDWIDTH GetIFBandwidth;
extern SET_IF_BANDWIDTH SetIFBandwidth;
extern GET_AGC GetAGC;
extern SET_AGC SetAGC;
extern GET_IF_GAIN GetIFGain;
extern SET_IF_GAIN SetIFGain;
extern ENABLE_AUDIO_FILTER EnableAudioFilter;
extern GET_AUDIO_FILTER GetAudioFilter;
extern SET_AUDIO_FILTER SetAudioFilter;
extern GET_SOFT_AGC GetSoftAGC;
extern SET_SOFT_AGC SetSoftAGC;
extern GET_NOTCH_FILTER GetNotchFilter;
extern SET_NOTCH_FILTER SetNotchFilter;
extern ENABLE_NOTCH_FILTER EnableNotchFilter;
extern GET_NOISE_BLANKER GetNoiseBlanker;
extern SET_NOISE_BLANKER SetNoiseBlanker;
extern LOAD_CALIBRATION_FILE LoadCalibrationFile;
extern UNLOAD_CALIBRATION_FILE UnloadCalibrationFile;
extern GET_ATTENUATOR GetAttenuator;
extern SET_ATTENUATOR SetAttenuator;
extern GET_RF_AMPLIFIER GetRFAmplifier;
extern SET_RF_AMPLIFIER SetRFAmplifier;
extern GET_INTERNAL_RSSI GetInternalRSSI;
extern GET_RAW_SIGNAL_STRENGTH GetRawSignalStrength;
extern GET_SIGNAL_STRENGTH_DBM GetSignalStrengthdBm;
extern GET_REF_CLOCK GetRefClock;
extern SET_REF_CLOCK SetRefClock;
extern STOP_SCANNING StopScanning;
extern START_SCANNING StartScanning;
extern GET_FRONT_PANEL_LED GetFrontPanelLED;
extern SET_FRONT_PANEL_LED SetFrontPanelLED;
extern IS_DEVICE_CONNECTED IsDeviceConnected;
extern GET_AUDIO_GAIN GetAudioGain;
extern SET_AUDIO_GAIN SetAudioGain;
extern GET_FMAF_SQUELCH_LEVEL GetFMAFSquelchLevel;
extern SET_FMAF_SQUELCH_LEVEL SetFMAFSquelchLevel;
extern GET_ISB_AUDIO_CHANNEL GetISBAudioChannel;
extern SET_ISB_AUDIO_CHANNEL SetISBAudioChannel;
extern GET_CW_TONE GetCWTone;
extern SET_CW_TONE SetCWTone;
extern GET_STATISTICS GetStatistics;
extern GET_API_VERSION GetAPIVersion;

};



int InitAPI(void);
void UninitAPI(void);

#endif
