#!/bin/bash

KERNELRELEASE=`uname -r`
KERNELDIR="/lib/modules/$KERNELRELEASE"
API=wrg315api.so
PLATFORM=`uname -m`
LD=/lib/ld-linux.so.2
LD_x86_64=/lib64/ld-linux-x86-64.so.2
PLATFORMS="i386 i486 i586 i686 x86_64"
LDS="${LD} ${LD} ${LD} ${LD} ${LD_x86_64}"

echo ""
echo "WiNRADiO G315 driver and API uninstaller"
echo ""

if [ $(id -ur) != 0 ]; then
    echo "Please, run this script as root."
    echo "Uninstallation aborted."
    echo ""
    exit 1
fi

echo "If the WiNRADiO G315 driver and API are uninstalled,"
echo "the applications that use them will not work."
echo -n "Are you sure you want to uninstall G315 driver and API? [n] "
read ANSWER

case $ANSWER in
    "y");;
    "Y");;
    *)
      exit 0;;
esac

echo ""


api=""

MODULELOADED=`/sbin/lsmod | grep wrg315 | wc -l`

if [ $MODULELOADED -ne 0 ]; then
    /sbin/rmmod wrg315 >/dev/null 2>&1
    if [ $? != 0 ]; then
	echo "ERROR: Unable to unload wrg315 kernel module."
	echo "Please close all the applications that use the module."
	echo ""
	exit 1
    fi
fi

if [ -f "$KERNELDIR/kernel/drivers/WiNRADiO/wrg315.ko" ]; then
    rm -f "$KERNELDIR/kernel/drivers/WiNRADiO/wrg315.ko" >/dev/null 2>&1
    /sbin/depmod -a
    echo "WiNRADiO G315 kernel module uninstalled."    
fi

echo -e "Uninstalling G315 API..."

for p in $PLATFORMS ; do
    f="lib/$p/$API"
    if [[ -f "$f" ]] ; then
    lib_dir=
    for l in $LDS ; do
        if test -x $l ; then
            $l --verify "$f" >/dev/null 2>&1
            r=$?
            case $r in
                0|2)
                    lib_dir=$($l --list "$f" 2>/dev/null | grep /libc.so | sed 's/.*\s\//\//g' | sed 's/\/libc.*//g')

                    if [[ "$lib_dir" != "" ]] ; then
                        if test -f "$lib_dir/$API" ; then                                
                                rm -f "$lib_dir/$API" >/dev/null 2>&1
                        fi
                    fi
                    break;
                ;;
                *)
                ;;
            esac
        fi
    done
    fi
done


echo ""
echo "Done."
echo ""

exit 0


